import { IRole } from 'aws-cdk-lib/aws-iam';
import { CfnBot, CfnBotAlias, CfnBotVersion } from 'aws-cdk-lib/aws-lex';
import { Construct } from 'constructs';
import { Locale } from './Locale';
import { ILogGroup } from 'aws-cdk-lib/aws-logs';
import { IBucket } from 'aws-cdk-lib/aws-s3';
export interface BotProps {
    /**
     * If provided, bot will send lex logs
     */
    readonly logGroup?: ILogGroup;
    /**
     * If provided, bot will record audio
     */
    readonly audioBucket?: IBucket;
    /**
     * Bot name
     */
    readonly name: string;
    /**
     * Bot description
     */
    readonly description?: string;
    readonly locales: Locale[];
    /**
     * Allows you to create a role externally.
     * Use this if all your bots use the same permissions
     */
    readonly role?: IRole;
    /**
     * @default 300
     */
    readonly idleSessionTtlInSeconds?: number;
    /**
     * @default 0.4
     */
    readonly nluConfidenceThreshold?: number;
}
/**
 * Defines a simplified interface for creating an Amazon Lex Bot.
 */
export declare class Bot extends Construct {
    private readonly props;
    readonly role: IRole;
    readonly cfnBot: CfnBot;
    readonly cfnBotVersion: CfnBotVersion;
    readonly cfnBotAlias: CfnBotAlias;
    constructor(scope: Construct, id: string, props: BotProps);
    private botAliasLocaleSettings;
    conversationLogSettings(aliasName: string): CfnBotAlias.ConversationLogSettingsProperty | undefined;
}
