import { IFunction } from 'aws-cdk-lib/aws-lambda';
import { CfnBot } from 'aws-cdk-lib/aws-lex';
import { Intent } from './Intent';
import { SlotType } from './SlotType';
export declare type VoiceEngine = 'generative' | 'long-form' | 'neural' | 'standard';
export interface LocaleCodeHook {
    /**
     * The lambda function that will be invoked
     */
    readonly fn: IFunction;
    /**
     * Whether to invoke the lambda for each dialog turn
     */
    readonly dialog?: boolean;
    /**
     * Whether to invoke the lambda for each intent fulfillment
     */
    readonly fulfillment?: boolean;
}
export interface LocaleProps {
    readonly localeId: string;
    readonly nluConfidenceThreshold?: number;
    readonly voiceId: string;
    readonly description?: string;
    readonly engine?: VoiceEngine;
    readonly intents?: Intent[];
    readonly slotTypes?: SlotType[];
    readonly codeHook?: LocaleCodeHook;
}
export declare class Locale {
    localeId: string;
    /**
     * If not provided, will default to bot default value
     */
    nluConfidenceThreshold?: number;
    voiceId: string;
    description?: string;
    /**
     * @default LexDefaults.engine
     */
    engine?: VoiceEngine;
    /**
     * Defines an intent and its associated utterances
     */
    intents?: Intent[];
    /**
     * Any non-standard slot types required
     */
    slotTypes?: SlotType[];
    /**
     * Optional dialog and fulfillment hooks
     */
    codeHook?: LocaleCodeHook;
    constructor(props: LocaleProps);
    toCdk(botNluConfidenceThreshold: number): CfnBot.BotLocaleProperty;
    addPermission(botAliasArn: string): void;
}
