import { CfnBot } from 'aws-cdk-lib/aws-lex';
export interface SlotTypeValue {
    /**
     * If 'resolutionStrategy' is set to 'TOP_RESOLUTION', this will be the resolved slot value if the slot is successfully filled
     */
    readonly sampleValue: string;
    /**
     * a list of phrases that you want the bot to resolve to the sample value
     */
    readonly synonyms?: string[];
}
export interface SlotTypeProps {
    readonly name: string;
    readonly description?: string;
    readonly values: SlotTypeValue[];
    readonly resolutionStrategy?: 'ORIGINAL_VALUE' | 'TOP_RESOLUTION';
}
export declare class SlotType {
    name: string;
    description?: string;
    values: SlotTypeValue[];
    /**
     * 'ORIGINAL_VALUE' (the default) will resolve to what the caller said, provided it is close to one the provided sample values.
     * 'TOP_RESOLUTION' will always resolve to a sample value, or not at all. Use this if you need to branch on slot values
     */
    resolutionStrategy?: 'ORIGINAL_VALUE' | 'TOP_RESOLUTION';
    constructor(props: SlotTypeProps);
    toCdk(): CfnBot.SlotTypeProperty;
}
